pub struct Clippy {
pub common: CommonOptions,
pub check: CheckOptions,
pub manifest_path: Option<PathBuf>,
pub release: bool,
pub ignore_rust_version: bool,
pub unit_graph: bool,
pub no_deps: bool,
pub fix: bool,
pub allow_dirty: bool,
pub allow_staged: bool,
pub args: Vec<String>,
}Expand description
Checks a package to catch common mistakes and improve your Rust code
Fields
common: CommonOptionscheck: CheckOptionsmanifest_path: Option<PathBuf>Path to Cargo.toml
release: boolBuild artifacts in release mode, with optimizations
ignore_rust_version: boolIgnore rust-version specification in packages
unit_graph: boolOutput build graph in JSON (unstable)
no_deps: boolRun Clippy only on the given crate, without linting the dependencies
fix: boolAutomatically apply lint suggestions. This flag implies –no-deps and –all-targets
allow_dirty: boolAllow applying fixes even if the working directory has changes
allow_staged: boolAllow applying fixes even if the index has changes
args: Vec<String>Arguments passed to rustc
Implementations
Methods from Deref<Target = CommonOptions>