pub struct CommonOptions {Show 18 fields
pub quiet: bool,
pub jobs: Option<usize>,
pub keep_going: bool,
pub profile: Option<String>,
pub features: Vec<String>,
pub all_features: bool,
pub no_default_features: bool,
pub target: Vec<String>,
pub target_dir: Option<PathBuf>,
pub message_format: Vec<String>,
pub verbose: u8,
pub color: Option<String>,
pub frozen: bool,
pub locked: bool,
pub offline: bool,
pub config: Vec<String>,
pub unstable_flags: Vec<String>,
pub timings: bool,
}Expand description
common cargo options
Fields
quiet: boolDo not print cargo log messages
jobs: Option<usize>Number of parallel jobs, defaults to # of CPUs.
keep_going: boolDo not abort the build as soon as there is an error
profile: Option<String>Build artifacts with the specified profile
features: Vec<String>Space or comma separated list of features to activate
all_features: boolActivate all available features
no_default_features: boolDo not activate the default feature
target: Vec<String>Build for the target triple
target_dir: Option<PathBuf>Directory for all generated artifacts
message_format: Vec<String>Error format
verbose: u8Use verbose output (-vv very verbose/build.rs output)
color: Option<String>Coloring
frozen: boolEquivalent to specifying both –locked and –offline
locked: boolAssert that Cargo.lock will remain unchanged
offline: boolRun without accessing the network
config: Vec<String>Override a configuration value
unstable_flags: Vec<String>Unstable (nightly-only) flags to Cargo, see ‘cargo -Z help’ for details
timings: boolOutput a build timing report at the end of the build
Implementations