pub struct Metadata {Show 15 fields
pub quiet: bool,
pub features: Vec<String>,
pub all_features: bool,
pub no_default_features: bool,
pub verbose: u8,
pub filter_platform: Vec<String>,
pub no_deps: bool,
pub manifest_path: Option<PathBuf>,
pub format_version: Option<String>,
pub color: Option<String>,
pub frozen: bool,
pub locked: bool,
pub offline: bool,
pub config: Vec<String>,
pub unstable_flags: Vec<String>,
}Expand description
Output the resolved dependencies of a package, the concrete used versions including overrides, in machine-readable format
Fields
quiet: boolDo not print cargo log messages
features: Vec<String>Space or comma separated list of features to activate
all_features: boolActivate all available features
no_default_features: boolDo not activate the default feature
verbose: u8Use verbose output (-vv very verbose/build.rs output)
filter_platform: Vec<String>Only include resolve dependencies matching the given target-triple
no_deps: boolOutput information only about the workspace members and don’t fetch dependencies
manifest_path: Option<PathBuf>Path to Cargo.toml
format_version: Option<String>Format version
color: Option<String>Coloring
frozen: boolEquivalent to specifying both –locked and –offline
locked: boolAssert that Cargo.lock will remain unchanged
offline: boolRun without accessing the network
config: Vec<String>Override a configuration value
unstable_flags: Vec<String>Unstable (nightly-only) flags to Cargo, see ‘cargo -Z help’ for details
Implementations