pub struct Rustc {Show 20 fields
pub common: CommonOptions,
pub manifest_path: Option<PathBuf>,
pub release: bool,
pub ignore_rust_version: bool,
pub unit_graph: bool,
pub packages: Vec<String>,
pub lib: bool,
pub bin: Vec<String>,
pub bins: bool,
pub example: Vec<String>,
pub examples: bool,
pub test: Vec<String>,
pub tests: bool,
pub bench: Vec<String>,
pub benches: bool,
pub all_targets: bool,
pub print: Option<String>,
pub crate_type: Vec<String>,
pub future_incompat_report: bool,
pub args: Vec<String>,
}Expand description
Compile a package, and pass extra options to the compiler
Fields
common: CommonOptionsmanifest_path: Option<PathBuf>Path to Cargo.toml
release: boolBuild artifacts in release mode, with optimizations
ignore_rust_version: boolIgnore rust-version specification in packages
unit_graph: boolOutput build graph in JSON (unstable)
packages: Vec<String>Package to build
lib: boolBuild only this package’s library
bin: Vec<String>Build only the specified binary
bins: boolBuild all binaries
example: Vec<String>Build only the specified example
examples: boolBuild all examples
test: Vec<String>Build only the specified test target
tests: boolBuild all targets that have test = true set
bench: Vec<String>Build only the specified bench target
benches: boolBuild all targets that have bench = true set
all_targets: boolBuild all targets
print: Option<String>Output compiler information without compiling
crate_type: Vec<String>Comma separated list of types of crates for the compiler to emit
future_incompat_report: boolOutputs a future incompatibility report at the end of the build
args: Vec<String>Extra rustc flags
Implementations
Methods from Deref<Target = CommonOptions>